@@ -550,7 +550,7 @@ $selectedTheme = get_selected_theme();
 	<div class='loginArea'>
 		<div class='cactiLoginLogo'></div>
 			<legend><?php print __('User Login');?></legend>
-			<form name='login' method='post' action='<?php print basename($_SERVER['PHP_SELF']);?>'>
+			<form name='login' method='post' action='<?php print get_current_page();?>'>
 				<input type='hidden' name='action' value='login'>
 				<?php api_plugin_hook_function('login_before', 
 					array(
