@@ -228,7 +228,7 @@ function automation_graph_rules_form_actions() {
 	/* setup some variables */
 	$automation_graph_rules_list = ''; $i = 0;
 	/* loop through each of the graphs selected on the previous page and get more info about them */
-	while (list($var,$val) = each($_POST)) {
+	foreach ($_POST as $var => $val) {
 		if (preg_match('/^chk_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
@@ -373,16 +373,16 @@ function automation_graph_rules_item_edit() {
 
 	$(function() {
 		toggle_operation();
-	toggle_operator();
+		toggle_operator();
 	});
 
 	function toggle_operation() {
 		if ($('#operation').val() == '<?php print AUTOMATION_OPER_RIGHT_BRACKET;?>') {
-			$('#field').val() = '';
+			$('#field').val('');
 			$('#field').prop('disabled', true);
-			$('#operator').val() = 0;
+			$('#operator').val(0);
 			$('#operator').prop('disabled', true);
-			$('#pattern').val() = '';
+			$('#pattern').val('');
 			$('#pattern').prop('disabled', true);
 		} else {
 			$('#field').prop('disabled', false);
@@ -762,7 +762,7 @@ function automation_graph_rules() {
 		function applyFilter() {
 			strURL = 'automation_graph_rules.php' + 
 				'?status='        + $('#status').val()+
-				'&filter='        + $('#filter').val()+
+				'&filter='        + escape($('#filter').val())+
 				'&rows='          + $('#rows').val()+
 				'&page='          + $('#page').val()+
 				'&snmp_query_id=' + $('#snmp_query_id').val()+
@@ -830,6 +830,9 @@ function automation_graph_rules() {
 		ON (agr.snmp_query_id=sq.id)
 		$sql_where");
 
+	$sql_order = get_order_string();
+	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
+
 	$automation_graph_rules_list = db_fetch_assoc("SELECT agr.id, agr.name, agr.snmp_query_id, agr.graph_type_id, 
 		agr.enabled, sq.name AS snmp_query_name, sqg.name AS graph_type_name 
 		FROM automation_graph_rules AS agr
@@ -838,8 +841,8 @@ function automation_graph_rules() {
 		LEFT JOIN snmp_query_graph AS sqg	
 		ON (agr.graph_type_id=sqg.id) 
 		$sql_where 
-		ORDER BY " . get_request_var('sort_column') . ' ' . get_request_var('sort_direction') . "
-		LIMIT " . ($rows*(get_request_var('page')-1)) . ',' . $rows);
+		$sql_order
+		$sql_limit");
 
 	$nav = html_nav_bar('automation_graph_rules.php?filter=' . get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 7, __('Graph Rules'), 'page', 'main');
 
