@@ -196,7 +196,7 @@ function form_automation_snmp_actions() {
 	/* setup some variables */
 	$snmp_groups = ''; $i = 0;
 	/* loop through each of the graphs selected on the previous page and get more info about them */
-	while (list($var,$val) = each($_POST)) {
+	foreach ($_POST as $var => $val) {
 		if (preg_match('/^chk_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
@@ -858,7 +858,7 @@ function automation_snmp() {
 	</tr>
 	<script type='text/javascript'>
 	function applyFilter() {
-		strURL = 'automation_snmp.php?filter='+$('#filter').val()+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&header=false';
+		strURL = 'automation_snmp.php?filter='+escape($('#filter').val())+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&header=false';
 		loadPageNoHeader(strURL);
 	}
 
@@ -900,6 +900,9 @@ function automation_snmp() {
 		GROUP BY asnmp.id
 		$sql_where");
 
+	$sql_order = get_order_string();
+	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
+
 	$snmp_groups = db_fetch_assoc("SELECT asnmp.*, COUNT(anw.id) AS networks,
 		COUNT(asnmpi.snmp_id) AS totals,
 		SUM(CASE WHEN asnmpi.snmp_version=1 THEN 1 ELSE 0 END) AS v1entries,
@@ -912,8 +915,8 @@ function automation_snmp() {
 		ON asnmp.id=asnmpi.snmp_id
 		GROUP BY asnmp.id
 		$sql_where
-		ORDER BY " . get_request_var('sort_column') . ' ' . get_request_var('sort_direction') . '
-		LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows);
+		$sql_order
+		$sql_limit");
 
 	$nav = html_nav_bar('automation_snmp.php?filter=' . get_request_var('filter'), MAX_DISPLAY_PAGES, get_request_var('page'), $rows, $total_rows, 12, __('SNMP Option Sets'), 'page', 'main');
 
@@ -967,7 +970,7 @@ function automation_snmp() {
 	<script type='text/javascript'>
 	function applyFilter() {
 		strURL  = 'automation_snmp.php?header=false&rows=' + $('#rows').val();
-		strURL += strURL + '&filter=' + $('#filter').val();
+		strURL += strURL + '&filter=' + escape($('#filter').val());
 		loadPageNoHeader(strURL);
 	}
 	</script>
