@@ -43,22 +43,41 @@ if ($script == 'graph_view.php' || $script == 'graph.php') {
 	}
 }
 
-if (!empty($refresh)) {
-	$refreshIsLogout = 'false';
-	if (!is_array($refresh)) {
-		$myrefresh['seconds'] = $refresh;
-		$myrefresh['page'] = $_SERVER['REQUEST_URI'] . (strpos($_SERVER['REQUEST_URI'], '?') ? '&':'?') . 'header=false';;
-	} else {
-		$myrefresh = $refresh;
-		$myrefresh['page'] .= (strpos($myrefresh['page'], '?') ? '&':'?') . 'header=false';
+if (isset($_SESSION['refresh'])) {
+	if (isset($_SESSION['refresh']['seconds'])) {
+		$myrefresh['seconds'] = $_SESSION['refresh']['seconds'];
+	}else{
+		$myrefresh['seconds'] = ini_get('session.gc_maxlifetime');
 	}
+
+    if (isset($_SESSION['refresh']['logout'])) {
+        $refreshIsLogout = $_SESSION['refresh']['logout'];
+    }else{
+		$refreshIsLogout = 'true';
+	}
+
+    if (isset($_SESSION['refresh']['page'])) {
+        $myrefresh['page'] = $_SESSION['refresh']['page'];
+    }else{
+		$myrefresh['page'] = $config['url_path'] . 'logout.php?action=timeout';
+	}
+
+	unset($_SESSION['refresh']);
+}elseif (isset($refresh) && is_array($refresh)) {
+	$refreshIsLogout = 'false';
+	$myrefresh['seconds'] = $refresh['seconds'];
+	$myrefresh['page']    = (strpos($refresh['page'], '?') ? '&':'?') . 'header=false';
+}elseif (isset($refresh)) {
+	$refreshIsLogout = 'false';
+	$myrefresh['seconds'] = $refresh;
+	$myrefresh['page']    = $_SERVER['REQUEST_URI'] . (strpos($_SERVER['REQUEST_URI'], '?') ? '&':'?') . 'header=false';;
 } elseif (read_config_option('auth_cache_enabled') == 'on' && isset($_COOKIE['cacti_remembers'])) {
 	$myrefresh['seconds'] = 99999999;
-	$myrefresh['page'] = 'index.php';
+	$myrefresh['page']    = 'index.php';
 	$refreshIsLogout = 'false';
 }else{
 	$myrefresh['seconds'] = ini_get('session.gc_maxlifetime');
-	$myrefresh['page'] = $config['url_path'] . 'logout.php?action=timeout';
+	$myrefresh['page']    = $config['url_path'] . 'logout.php?action=timeout';
 	$refreshIsLogout = 'true';
 } ?> 
 <script type='text/javascript'>
@@ -68,4 +87,7 @@ if (!empty($refresh)) {
 	var refreshMSeconds=<?php print $myrefresh['seconds']*1000;?>;
 	var urlPath='<?php print $config['url_path'];?>';
 	var previousPage='';
+	var requestURI='<?php print $_SERVER['REQUEST_URI'];?>';
+	var searchFilter='<?php print __('Enter a search term');?>';
+	var searchRFilter='<?php print __('Enter a regular expression');?>';
 </script>
