@@ -409,7 +409,7 @@ function install_file_paths () {
 		if (config_value_exists('path_spine')) {
 			$input['path_spine']['default'] = read_config_option('path_spine');
 		}else if (!empty($which_spine)) {
-			$input['path_spine']['default'] = $which_spine . '/spine.exe';
+			$input['path_spine']['default'] = $which_spine;
 		}else{
 			$input['path_spine']['default'] = 'c:/spine/bin/spine.exe';
 		}
