@@ -263,7 +263,9 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 					$graph_item['cdef_id'] = $make0_cdef;
 
 					# try to pick the best totaling cf id
-					$graph_item['consolidation_function_id'] = db_fetch_cell('SELECT DISTINCT consolidation_function_id FROM graph_templates_item WHERE color_id>0 AND ' . array_to_sql_or($member_graphs, 'local_graph_id') . ' LIMIT 1');
+					$graph_item['consolidation_function_id'] = db_fetch_cell('SELECT DISTINCT consolidation_function_id 
+						FROM graph_templates_item 
+						WHERE color_id>0 AND ' . array_to_sql_or($member_graphs, 'local_graph_id') . ' LIMIT 1');
 				}
 			}
 
@@ -506,7 +508,7 @@ function aggregate_validate_graph_params($posted, $has_override = false) {
  *
  */
 function aggregate_validate_graph_items($posted, &$graph_items) {
-	while (list($var,$val) = each($posted)) {
+	foreach ($_POST as $var => $val) {
 		/* work on color_templates */
 		if (preg_match('/^agg_color_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
@@ -1224,10 +1226,13 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 	if (sizeof($item_list)) {
 		foreach ($item_list as $item) {
 			/* graph grouping display logic */
-			$this_row_style = ''; $use_custom_class = false; $hard_return = '';
+			$this_row_style = ''; 
+			$use_custom_class = false; 
+			$hard_return = '';
 
-			if ($graph_item_types{$item['graph_type_id']} != 'GPRINT') {
-				$this_row_style = 'font-weight: bold;'; $use_custom_class = true;
+			if (!preg_match('/(GPRINT|TEXTALIGN|HRULE|VRULE|TICK)/', $graph_item_types[$item['graph_type_id']])) {
+				$this_row_style = 'font-weight: bold;'; 
+				$use_custom_class = true;
 
 				if ($group_counter % 2 == 0) {
 					$customClass  = 'graphItem';
@@ -1243,13 +1248,23 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 			$force_skip = false;
 
 			switch (true) {
+				case preg_match('/(TEXTALIGN)/', $_graph_type_name):
+					$matrix_title = 'TEXTALIGN: ' . ucfirst($item['textalign']);
+					break;
+				case preg_match('/(TICK)/', $_graph_type_name):
+					$matrix_title = '(' . $item['data_source_name'] . '): ' . $item['text_format'];
+					break;
 				case preg_match('/(AREA|STACK|GPRINT|LINE[123])/', $_graph_type_name):
 					$matrix_title = $item['text_format'];
 					break;
-				case preg_match('/(HRULE|VRULE)/', $_graph_type_name):
+				case preg_match('/(HRULE)/', $_graph_type_name):
 					$force_skip = true;
 					$matrix_title = 'HRULE: ' . $item['value'];
 					break;
+				case preg_match('/(VRULE)/', $_graph_type_name):
+					$force_skip = true;
+					$matrix_title = 'VRULE: ' . $item['value'];
+					break;
 				case preg_match('/(COMMENT)/', $_graph_type_name):
 					$force_skip = true;
 					$matrix_title = 'COMMENT: ' . $item['text_format'];
@@ -1286,6 +1301,7 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 			if ($item['hard_return'] == 'on') {
 				$hard_return = '<strong><font color="#FF0000">&lt;HR&gt;</font></strong>';
 			}
+
 			print "<td style='$this_row_style'>" . htmlspecialchars($matrix_title) . $hard_return . "</td>\n";
 
 			/* column 'Graph Item Type' */
@@ -1354,43 +1370,43 @@ function draw_aggregate_template_graph_config($aggregate_template_id, $graph_tem
 	$aggregate_templates_graph = db_fetch_row_prepared('SELECT * FROM aggregate_graph_templates_graph WHERE aggregate_template_id = ?', array($aggregate_template_id));
 	$graph_templates_graph     = db_fetch_row_prepared('SELECT * FROM graph_templates_graph WHERE graph_template_id = ?', array($graph_template_id));
 
-		$form_array = array();
+	$form_array = array();
 
-		while (list($field_name, $field_array) = each($struct_graph)) {
-			if ($field_name == 'title')
-				continue;
+	foreach ($struct_graph as $field_name => $field_array) {
+		if ($field_name == 'title')
+			continue;
 
-			if ($field_array['method'] != 'spacer') {
-				$form_array += array($field_name => $struct_graph[$field_name]);
+		if ($field_array['method'] != 'spacer') {
+			$form_array += array($field_name => $struct_graph[$field_name]);
 
-				/* value from graph template or aggregate graph template 
-				(based on value of t_$field_name of aggregate_template_graph) */
-				if (sizeof($aggregate_templates_graph) && $aggregate_templates_graph['t_'.$field_name] == 'on') {
-					$value = $aggregate_templates_graph[$field_name];
-				}else{
-					$value = $graph_templates_graph[$field_name];
-				}
-
-				$form_array[$field_name]['value'] = $value;
-				$form_array[$field_name]['sub_checkbox'] = array(
-					'name' => 't_' . $field_name,
-					'friendly_name' => __('Override this Value'). '<br>',
-					'value' => (sizeof($aggregate_templates_graph) ? $aggregate_templates_graph{'t_' . $field_name} : ''),
-					'on_change' => 'toggleFieldEnabled(this);'
-				);
+			/* value from graph template or aggregate graph template
+			(based on value of t_$field_name of aggregate_template_graph) */
+			if (sizeof($aggregate_templates_graph) && $aggregate_templates_graph['t_'.$field_name] == 'on') {
+				$value = $aggregate_templates_graph[$field_name];
 			}else{
-				$form_array += array($field_name => $struct_graph[$field_name]);
+				$value = $graph_templates_graph[$field_name];
 			}
+
+			$form_array[$field_name]['value'] = $value;
+			$form_array[$field_name]['sub_checkbox'] = array(
+				'name' => 't_' . $field_name,
+				'friendly_name' => __('Override this Value'). '<br>',
+				'value' => (sizeof($aggregate_templates_graph) ? $aggregate_templates_graph{'t_' . $field_name} : ''),
+				'on_change' => 'toggleFieldEnabled(this);'
+			);
+		}else{
+			$form_array += array($field_name => $struct_graph[$field_name]);
 		}
+	}
 
-		draw_edit_form(
-			array(
-				'config' => array('no_form_tag' => true),
-				'fields' => $form_array
-			)
-		);
+	draw_edit_form(
+		array(
+			'config' => array('no_form_tag' => true),
+			'fields' => $form_array
+		)
+	);
 
-		/* some javascript do dinamically disable non-overriden fields */
+	/* some javascript do dinamically disable non-overriden fields */
 ?>
 <script type='text/javascript'>
 
