@@ -422,7 +422,7 @@ function draw_dhtml_tree_level_graphing($tree_id, $parent = 0, $export = false)
 
 										if ($data_query['id'] > 0) {
 											$dhtml_tree[] = "\t\t\t\t\t\t\t<ul>\n";
-											while (list($snmp_index, $sort_field_value) = each($sort_field_data)) {
+											foreach ($sort_field_data as $snmp_index => $sort_field_value) {
 												$dhtml_tree[] = "\t\t\t\t\t\t\t\t<li id='tbranch-" . $leaf['id'] . '-dq-' . $data_query['id'] . '-' . urlencode($snmp_index) . "' data-jstree='{ \"type\" : \"graph\" }'><a class='treepick' href='" . htmlspecialchars('graph_view.php?action=tree&node=tbranch-' . $leaf['id'] . '&hgd=dqi:' . $data_query['id'] . ':' . $snmp_index) . "'>" . htmlspecialchars($sort_field_value) . "</a></li>\n";
 											}
 
@@ -645,7 +645,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 					</td>
 					<?php if (is_view_allowed('graph_settings')) {?>
 					<td>
-						<input type='button' id='save' value='<?php print __('Save');?>' title='<?php print __('Save the current Graphs, Columns, Thumbnail, Preset, and Timeshift preferences to your profile');?>' onClick='saveGraphFilter("tree")'>
+						<input id='save' type='button' value='<?php print __('Save');?>' title='<?php print __('Save the current Graphs, Columns, Thumbnail, Preset, and Timeshift preferences to your profile');?>' onClick='saveGraphFilter("tree")'>
 					</td>
 					<td id='text'></td>
 					<?php }?>
@@ -657,7 +657,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<?php print __('Graphs');?>
 					</td>
 					<td>
-						<select name='graphs' id='graphs' onChange='applyGraphFilter()'>
+						<select id='graphs' onChange='applyGraphFilter()'>
 							<?php
 							if (sizeof($graphs_per_page) > 0) {
 							foreach ($graphs_per_page as $key => $value) {
@@ -671,17 +671,13 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<?php print __('Columns');?>
 					</td>
 					<td>
-						<select name='columns' id='columns' onChange='applyGraphFilter()' <?php print get_request_var('thumbnails') == 'false' ? 'disabled':'';?>>
-							<?php if (get_request_var('thumbnails') == 'false') {?>
-							<option value='<?php print get_request_var('columns');?>' selected><?php print __('N/A');?></option>
-							<?php }else{?>
+						<select id='columns' onChange='applyGraphFilter()'>
 							<option value='1' <?php print (get_request_var('columns') == '1' ? ' selected':'');?>><?php print __('%d Column', 1);?></option>
 							<option value='2' <?php print (get_request_var('columns') == '2' ? ' selected':'');?>><?php print __('%d Columns', 2);?></option>
 							<option value='3' <?php print (get_request_var('columns') == '3' ? ' selected':'');?>><?php print __('%d Columns', 3);?></option>
 							<option value='4' <?php print (get_request_var('columns') == '4' ? ' selected':'');?>><?php print __('%d Columns', 4);?></option>
 							<option value='5' <?php print (get_request_var('columns') == '5' ? ' selected':'');?>><?php print __('%d Columns', 5);?></option>
 							<option value='6' <?php print (get_request_var('columns') == '6' ? ' selected':'');?>><?php print __('%d Columns', 6);?></option>
-							<?php }?>
 						</select>
 					</td>
 					<td>
@@ -704,7 +700,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<?php print __('Presets');?>
 					</td>
 					<td>
-						<select id='predefined_timespan' name='predefined_timespan' onChange='applyGraphTimespan()'>
+						<select id='predefined_timespan' onChange='applyGraphTimespan()'>
 							<?php
 							if (isset($_SESSION['custom'])) {
 								$graph_timespans[GT_CUSTOM] = __('Custom');
@@ -749,7 +745,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<i class='shiftArrow fa fa-backward' onClick='timeshiftGraphFilterLeft()' title='<?php print __('Shift Time Backward');?>'></i>
 					</td>
 					<td>
-						<select id='predefined_timeshift' name='predefined_timeshift' title='<?php print __('Define Shifting Interval');?>'>
+						<select id='predefined_timeshift' title='<?php print __('Define Shifting Interval');?>'>
 							<?php
 							$start_val = 1;
 							$end_val = sizeof($graph_timeshifts)+1;
@@ -776,7 +772,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<?php print __('Window');?>
 					</td>
 					<td>
-						<select name='graph_start' id='graph_start' onChange='imageOptionsChanged("timespan")'>
+						<select id='graph_start' onChange='imageOptionsChanged("timespan")'>
 							<?php
 							foreach ($realtime_window as $interval => $text) {
 								printf('<option value="%d"%s>%s</option>', $interval, $interval == $_SESSION['sess_realtime_window'] ? ' selected="selected"' : '', $text);
@@ -788,7 +784,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						<?php print __('Refresh');?>
 					</td>
 					<td>
-						<select name='ds_step' id='ds_step' onChange="imageOptionsChanged('interval')">
+						<select id='ds_step' onChange="imageOptionsChanged('interval')">
 							<?php
 							foreach ($realtime_refresh as $interval => $text) {
 								printf('<option value="%d"%s>%s</option>', $interval, $interval == $_SESSION['sess_realtime_dsstep'] ? ' selected="selected"' : '', $text);
@@ -1059,10 +1055,10 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 					}
 
 					/* using the sorted data as they key; grab each snmp index from the master list */
-					while (list($snmp_index, $sort_field_value) = each($sort_field_data)) {
+					foreach ($sort_field_data as $snmp_index => $sort_field_value) {
 						/* render each graph for the current data query index */
 						if (isset($snmp_index_to_graph[$snmp_index])) {
-							while (list($local_graph_id, $graph_title) = each($snmp_index_to_graph[$snmp_index])) {
+							foreach ($snmp_index_to_graph[$snmp_index] as $local_graph_id => $graph_title) {
 								/* reformat the array so it's compatable with the html_graph* area functions */
 								array_push($graph_list, array('data_query_name' => $data_query['name'], 'sort_field_value' => $sort_field_value, 'local_graph_id' => $local_graph_id, 'title_cache' => $graph_title, 'height' => $graphs_height[$graph['local_graph_id']], 'width' => $graphs_width[$graph['local_graph_id']]));
 							}
@@ -1083,7 +1079,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 	html_start_box('', '100%', '', '3', 'center', '');
 
 	/* start graph display */
-	print "<tr class='tableHeader'><td style='width:390px;' colspan='11' class='graphSubHeaderColumn textHeaderDark'>$title</td></tr>";
+	print "<tr class='tableHeader'><td style='width:390px;' colspan='" . get_request_var('columns') . "' class='graphSubHeaderColumn textHeaderDark'>$title</td></tr>";
 
 	$i = get_request_var('graphs') * (get_request_var('page') - 1);
 	$last_graph = $i + get_request_var('graphs');
@@ -1097,7 +1093,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 	if (get_request_var('thumbnails') == 'true' || get_request_var('thumbnails') == 'on') {
 		html_graph_thumbnail_area($new_graph_list, '', 'view_type=tree&graph_start=' . get_current_graph_start() . '&graph_end=' . get_current_graph_end(), '', get_request_var('columns'));
 	}else{
-		html_graph_area($new_graph_list, '', 'view_type=tree&graph_start=' . get_current_graph_start() . '&graph_end=' . get_current_graph_end(), '', 1);
+		html_graph_area($new_graph_list, '', 'view_type=tree&graph_start=' . get_current_graph_start() . '&graph_end=' . get_current_graph_end(), '', get_request_var('columns'));
 	}
 
 	if (!empty($leaf_id)) {
