@@ -66,8 +66,11 @@ function repopulate_poller_cache() {
 }
 
 function update_poller_cache_from_query($host_id, $data_query_id) {
-	$poller_data = db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' * FROM data_local 
-		WHERE host_id = ?  AND snmp_query_id = ?', array($host_id, $data_query_id));
+	$poller_data = db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' * 
+		FROM data_local 
+		WHERE host_id = ?
+		AND snmp_query_id = ?',
+		array($host_id, $data_query_id));
 
 	$i = 0;
 	$poller_items = $local_data_ids = array();
@@ -91,11 +94,18 @@ function update_poller_cache_from_query($host_id, $data_query_id) {
 		}
 	}
 
-	$poller_ids = array_rekey(db_fetch_assoc_prepared('SELECT DISTINCT poller_id FROM poller_item WHERE host_id = ?', array($host_id)), 'poller_id', 'poller_id');
+	$poller_ids = array_rekey(
+		db_fetch_assoc_prepared('SELECT DISTINCT poller_id 
+			FROM poller_item 
+			WHERE host_id = ?', 
+			array($host_id)), 
+		'poller_id', 'poller_id'
+	);
+
 	if (sizeof($poller_ids)) {
-	foreach($poller_ids as $poller_id) {
-		api_data_source_cache_crc_update($poller_id);
-	}
+		foreach($poller_ids as $poller_id) {
+			api_data_source_cache_crc_update($poller_id);
+		}
 	}
 }
 
@@ -326,13 +336,13 @@ function update_poller_cache($data_source, $commit = false) {
 							/* fall back to non-script server actions if the user is running a version of php older than 4.3 */
 							if (($data_input['type_id'] == DATA_INPUT_TYPE_QUERY_SCRIPT_SERVER) && (function_exists('proc_open'))) {
 								$action = POLLER_ACTION_SCRIPT_PHP;
-								$script_path = get_script_query_path((isset($script_queries['arg_prepend']) ? $script_queries['arg_prepend'] : '') . ' ' . $script_queries['arg_get'] . ' ' . $identifier . ' ' . escapeshellarg($data_source['snmp_index']), $script_queries['script_path'] . ' ' . $script_queries['script_function'], $data_source['host_id']);
+								$script_path = get_script_query_path((isset($script_queries['arg_prepend']) ? $script_queries['arg_prepend'] : '') . ' ' . $script_queries['arg_get'] . ' ' . $identifier . ' ' . cacti_escapeshellarg($data_source['snmp_index']), $script_queries['script_path'] . ' ' . $script_queries['script_function'], $data_source['host_id']);
 							}else if (($data_input['type_id'] == DATA_INPUT_TYPE_QUERY_SCRIPT_SERVER) && (!function_exists('proc_open'))) {
 								$action = POLLER_ACTION_SCRIPT;
 								$script_path = read_config_option('path_php_binary') . ' -q ' . get_script_query_path((isset($script_queries['arg_prepend']) ? $script_queries['arg_prepend'] : '') . ' ' . $script_queries['arg_get'] . ' ' . $identifier . ' ' . $data_source['snmp_index'], $script_queries['script_path'], $data_source['host_id']);
 							}else{
 								$action = POLLER_ACTION_SCRIPT;
-								$script_path = get_script_query_path((isset($script_queries['arg_prepend']) ? $script_queries['arg_prepend'] : '') . ' ' . $script_queries['arg_get'] . ' ' . $identifier . ' ' . escapeshellarg($data_source['snmp_index']), $script_queries['script_path'], $data_source['host_id']);
+								$script_path = get_script_query_path((isset($script_queries['arg_prepend']) ? $script_queries['arg_prepend'] : '') . ' ' . $script_queries['arg_get'] . ' ' . $identifier . ' ' . cacti_escapeshellarg($data_source['snmp_index']), $script_queries['script_path'], $data_source['host_id']);
 							}
 						}
 
@@ -549,25 +559,23 @@ function push_out_host($host_id, $local_data_id = 0, $data_template_id = 0) {
 				array($data_source['data_input_id'], $data_source['local_data_template_data_id']));
 		}
 
-		reset($template_fields{$data_source['local_data_template_data_id']});
-
 		/* loop through each field contained in the data template and push out a host value if:
 		 - the field is a valid "host field"
 		 - the value of the field is empty
 		 - the field is set to 'templated' */
 		if (sizeof($template_fields{$data_source['local_data_template_data_id']})) {
-		foreach ($template_fields{$data_source['local_data_template_data_id']} as $template_field) {
-			if ((preg_match('/^' . VALID_HOST_FIELDS . '$/i', $template_field['type_code'])) && ($template_field['value'] == '') && ($template_field['t_value'] == '')) {
-				// handle special case type_code
-				if ($template_field['type_code'] == 'host_id') $template_field['type_code'] = 'id';
+			foreach ($template_fields[$data_source['local_data_template_data_id']] as $template_field) {
+				if ((preg_match('/^' . VALID_HOST_FIELDS . '$/i', $template_field['type_code'])) && ($template_field['value'] == '') && ($template_field['t_value'] == '')) {
+					// handle special case type_code
+					if ($template_field['type_code'] == 'host_id') $template_field['type_code'] = 'id';
 
-				db_execute_prepared('REPLACE INTO data_input_data 
-					(data_input_field_id, data_template_data_id, value) 
-					VALUES (?, ?, ?)', 
-					array($template_field['id'], $data_source['id'], $host[$template_field['type_code']]));
+					db_execute_prepared('REPLACE INTO data_input_data 
+						(data_input_field_id, data_template_data_id, value) 
+						VALUES (?, ?, ?)',
+						array($template_field['id'], $data_source['id'], $host[$template_field['type_code']]));
+				}
 			}
 		}
-		}
 
 		/* flag an update to the poller cache as well */
 		$local_data_ids[] = $data_source['local_data_id'];
@@ -943,10 +951,10 @@ function utilities_php_modules() {
 }
 
 function memory_bytes($val) {
-	$val = trim($val);
+	$val  = trim($val);
 	$last = strtolower($val{strlen($val)-1});
+	$val  = trim($val, 'GMKgmk');
 	switch($last) {
-		// The 'G' modifier is available since PHP 5.1.0
 		case 'g':
 			$val *= 1024;
 		case 'm':
