@@ -165,7 +165,7 @@ function form_actions() {
 	$page_list = ''; $i = 0;
 
 	/* loop through each of the pages selected on the previous page and get more info about them */
-	while (list($var,$val) = each($_POST)) {
+	foreach ($_POST as $var => $val) {
 		if (preg_match('/^chk_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
@@ -279,7 +279,7 @@ function pages() {
 	<script type='text/javascript'>
 	function applyFilter() {
 		strURL  = 'links.php?rows=' + $('#rows').val();
-		strURL += '&filter=' + $('#filter').val();
+		strURL += '&filter=' + escape($('#filter').val());
 		strURL += '&header=false';
 		loadPageNoHeader(strURL);
 	}
@@ -353,14 +353,15 @@ function pages() {
 		$sql_where = '';
 	}
 
-	$limit = ' LIMIT ' . ($rows*(get_request_var('page') - 1)) . ", $rows";
-	$sort  = ' ORDER BY ' . get_request_var('sort_column') . ' ' . (get_request_var('sort_colomn') == 'sortorder' ? 'ASC':get_request_var('sort_direction'));
+	$sql_order = get_order_string();
+	$sql_order = str_replace('sortorder DESC', 'sortorder ASC', $sql_order);
+	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
 
 	$pages = db_fetch_assoc("SELECT *
 		FROM external_links
 		$sql_where
-		$sort
-		$limit");
+		$sql_order
+		$sql_limit");
 
 	$total_rows = db_fetch_cell('SELECT COUNT(*) FROM external_links');
 
