@@ -257,7 +257,7 @@ function form_actions() {
 	$pollers = ''; $i = 0;
 
 	/* loop through each of the graphs selected on the previous page and get more info about them */
-	while (list($var,$val) = each($_POST)) {
+	foreach ($_POST as $var => $val) {
 		if (preg_match('/^chk_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
@@ -537,7 +537,7 @@ function pollers() {
 			<script type='text/javascript'>
 
 			function applyFilter() {
-				strURL = 'pollers.php?filter='+$('#filter').val()+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&header=false';
+				strURL = 'pollers.php?filter='+escape($('#filter').val())+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&header=false';
 				loadPageNoHeader(strURL);
 			}
 
@@ -633,10 +633,10 @@ function pollers() {
 			form_selectable_cell($poller['hostname'], $poller['id'], '', 'right');
 			form_selectable_cell($poller_status[$poller['status']], $poller['id'], '', 'center');
 			form_selectable_cell(number_format_i18n($poller['total_time'], 2), $poller['id'], '', 'right');
-			form_selectable_cell(number_format_i18n($poller['hosts']), $poller['id'], '', 'right');
-			form_selectable_cell(number_format_i18n($poller['snmp']), $poller['id'], '', 'right');
-			form_selectable_cell(number_format_i18n($poller['script']), $poller['id'], '', 'right');
-			form_selectable_cell(number_format_i18n($poller['server']), $poller['id'], '', 'right');
+			form_selectable_cell(number_format_i18n($poller['hosts'], '-1'), $poller['id'], '', 'right');
+			form_selectable_cell(number_format_i18n($poller['snmp'], '-1'), $poller['id'], '', 'right');
+			form_selectable_cell(number_format_i18n($poller['script'], '-1'), $poller['id'], '', 'right');
+			form_selectable_cell(number_format_i18n($poller['server'], '-1'), $poller['id'], '', 'right');
 			form_selectable_cell($poller['last_update'], $poller['id'], '', 'right');
 			form_selectable_cell($poller['last_status'], $poller['id'], '', 'right');
 			form_checkbox_cell($poller['name'], $poller['id'], $disabled);
