@@ -459,7 +459,7 @@ function form_actions() {
 	$tree_list = ''; $i = 0;
 
 	/* loop through each of the selected items */
-	while (list($var,$val) = each($_POST)) {
+	foreach ($_POST as $var => $val) {
 		if (preg_match('/^chk_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
@@ -1444,7 +1444,7 @@ function tree() {
 	<script type='text/javascript'>
 	function applyFilter() {
 		strURL  = 'tree.php?rows=' + $('#rows').val();
-		strURL += '&filter=' + $('#filter').val();
+		strURL += '&filter=' + escape($('#filter').val());
 		strURL += '&page=' + $('#page').val();
 		strURL += '&header=false';
 		loadPageNoHeader(strURL);
